pub struct TaskMeta {
pub id: String,
pub title: String,
pub status: TaskStatus,
pub priority: Option<String>,
pub labels: Option<Vec<String>>,
pub milestone: Option<String>,
pub depends_on: Option<Vec<String>>,
}Fields
id: Stringtitle: Stringstatus: TaskStatuspriority: Option<String>labels: Option<Vec<String>>milestone: Option<String>depends_on: Option<Vec<String>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TaskMeta
impl<'de> Deserialize<'de> for TaskMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskMeta
impl JsonSchema for TaskMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for TaskMeta